cheesecake.cheesecake_index.IndexDocstrings

Package cheesecake :: Module cheesecake_index :: Class IndexDocstrings |
[show private | hide private]
[frames | no frames]

## Type IndexDocstrings

    object --+
             |
         Index --+
                 |
                IndexDocstrings

Compute how many objects have relevant docstrings.

Method Summary
| `compute(self, object_cnt, docstring_cnt)`
Inherited from Index
| ``__init__`(self, *indices)`
| ``__getitem__`(self, name)`
| ``add_info`(self, info_line)` Add information about index computation process, which will be visible with --verbose flag.
| ``add_subindex`(self, index)` Add subindex.
| ``decide`(self, cheesecake, when)` Decide if this index should be computed.
| ``decide_after_download`(self, cheesecake)`
| ``decide_before_download`(self, cheesecake)`
| ``get_info`(self)`
| ``print_info`(self)` Print index name padded with dots, followed by value and details.
| ``remove_subindex`(self, index_name)` Remove subindex (refered by name).
| ``_get_max_value`(self)`
| ``_get_requirements`(self)`
| ``_iter_indices`(self)` Iterate over each subindex and yield their values.
| ``_print_info_many`(self)`
| ``_print_info_one`(self)`
| ``compute_with`(self, cheesecake)`
Inherited from object
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__repr__`(x)` x.__repr__() <==> repr(x)
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| ``__str__`(x)` x.__str__() <==> str(x)

Property Summary
Inherited from Index
| `requirements`

Class Variable Summary
`int` | `max_value` = 100
`str` | `name` = `'IndexDocstrings'`
Inherited from Index
`str` | `details` = `''`
`str` | `info` = `''`
`NoneType` | `subindices` = None
`int` | `value` = -1

Class Variable Details

    ### max_value Type: `int` Value:
        100

    ### name Type: `str` Value:
        'IndexDocstrings'

Generated by Epydoc 2.1 on Fri Feb 9 02:15:13 2007 | http://epydoc.sf.net